==> youqian-center-api-2.0.12-3-20200306.033344-1-sources.jar: cn/com/duiba/youqian/center/api/request/template/TemplateOtherFieldVO.java <==
package cn.com.duiba.youqian.center.api.request.template;

import cn.com.duiba.youqian.center.api.annotation.TempField;
import lombok.Data;
import lombok.Getter;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;

@Data
public class TemplateOtherFieldVO implements Serializable {
    @TempField(name = "其他约定事项")
    private String otherDesc;

    @TempField(name = "定金")
    private String firstPayment;

    @TempField(name = "定金支付时间")
    private String firstPaymentTime;

    @TempField(name = "尾款")
    private String lastPayment;

    @TempField(name = "尾款支付时间")
    private String lastPaymentTime;

    @TempField(name = "付款金额")
    private String payment;

    @TempField(name = "付款时间")
    private String paymentTime;

    @TempField(name = "运费")
    private String freight;

    @TempField(name = "物流运输")
    private String transportWay;

    private Integer transportWayIndex;

    @TempField(name = "交货时间")
    private String deliveryTime;

    @TempField(name = "交货地址")
    private String deliveryAddress;

    @TempField(name = "是否定金")
    private Boolean isPayment;

    public TemplateOtherFieldVO format(){
        this.setTransportWay(TransportWayEnum.get(StringUtils.isEmpty(this.getTransportWay())?null:Integer.parseInt(this.getTransportWay())));
        this.setFirstPaymentTime(FirstPaymentEnum.get(StringUtils.isEmpty(this.getFirstPaymentTime())?null:Integer.parseInt(this.getFirstPaymentTime())));
        this.setPaymentTime(LastPaymentEnum.get(StringUtils.isEmpty(this.getPaymentTime())?null:Integer.parseInt(this.getPaymentTime())));
        this.setLastPaymentTime(LastPaymentEnum.get(StringUtils.isEmpty(this.getLastPaymentTime())?null:Integer.parseInt(this.getLastPaymentTime())));
        return this;
    }

    @Getter
    public enum TransportWayEnum{
        TRANSPORT_1(0,"甲方上门自提"),
        TRANSPORT_2(1,"乙方送货上门"),
        TRANSPORT_3(2,"以【备注】约定为准");
        private Integer code;
        private String msg;
        TransportWayEnum(Integer code,String msg){
            this.code = code;
            this.msg = msg;
        }
        public static String get(Integer code){
            code = code == null?0:code;
            for(TransportWayEnum transport : values()){
                if(code.equals(transport.getCode())){
                    return transport.getMsg();
                }
            }
            return "";
        }

    }
    @Getter
    enum FirstPaymentEnum{
        PAYMENT_1(0,"发货前7个工作日内"),
        PAYMENT_2(1,"以【备注】约定为准");
        private Integer code;
        private String msg;
        FirstPaymentEnum(Integer code,String msg){
            this.code = code;
            this.msg = msg;
        }
        public static String get(Integer code){
            code = code == null?0:code;
            for(FirstPaymentEnum firstPaymentEnum : values()){
                if(code.equals(firstPaymentEnum.getCode())){
                    return firstPaymentEnum.getMsg();
                }
            }
            return "";
        }
    }
    @Getter
    enum LastPaymentEnum{
        PAYMENT_1(0,"收货后7个工作日内"),
        PAYMENT_2(1,"月结(次月前7个工作日内)"),
        PAYMENT_3(2,"以【备注】约定为准");
        private Integer code;
        private String msg;
        LastPaymentEnum(Integer code,String msg){
            this.code = code;
            this.msg = msg;
        }
        public static String get(Integer code){
            code = code == null?0:code;
            for(LastPaymentEnum lastPaymentEnum : values()){
                if(code.equals(lastPaymentEnum.getCode())){
                    return lastPaymentEnum.getMsg();
                }
            }
            return "";
        }
    }

}

==> youqian-center-api-2.0.13-1-20200306.061328-2-sources.jar: cn/com/duiba/youqian/center/api/request/template/TemplateOtherFieldVO.java <==
package cn.com.duiba.youqian.center.api.request.template;

import cn.com.duiba.youqian.center.api.annotation.TempField;
import lombok.Data;
import lombok.Getter;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;

@Data
public class TemplateOtherFieldVO implements Serializable {
    @TempField(name = "其他约定事项")
    private String otherDesc;

    @TempField(name = "定金")
    private String firstPayment;

    @TempField(name = "定金支付时间")
    private String firstPaymentTime;

    @TempField(name = "尾款")
    private String lastPayment;

    @TempField(name = "尾款支付时间")
    private String lastPaymentTime;

    @TempField(name = "付款金额")
    private String payment;

    @TempField(name = "付款时间")
    private String paymentTime;

    @TempField(name = "运费")
    private String freight;

    @TempField(name = "物流运输")
    private String transportWay;

    private Integer transportWayIndex;

    @TempField(name = "交货时间")
    private String deliveryTime;

    @TempField(name = "交货地址")
    private String deliveryAddress;

    @TempField(name = "是否定金")
    private Boolean isPayment;

    @TempField(name = "税费")
    private String tax;

    @TempField(name = "货物是否含税")
    private Boolean isTax;

    @TempField(name = "发票")
    private Integer invoiceId;

    public TemplateOtherFieldVO format(){
        this.setTransportWay(TransportWayEnum.get(StringUtils.isEmpty(this.getTransportWay())?null:Integer.parseInt(this.getTransportWay())));
        this.setFirstPaymentTime(FirstPaymentEnum.get(StringUtils.isEmpty(this.getFirstPaymentTime())?null:Integer.parseInt(this.getFirstPaymentTime())));
        this.setPaymentTime(LastPaymentEnum.get(StringUtils.isEmpty(this.getPaymentTime())?null:Integer.parseInt(this.getPaymentTime())));
        this.setLastPaymentTime(LastPaymentEnum.get(StringUtils.isEmpty(this.getLastPaymentTime())?null:Integer.parseInt(this.getLastPaymentTime())));
        return this;
    }

    @Getter
    public enum TransportWayEnum{
        TRANSPORT_1(0,"甲方上门自提"),
        TRANSPORT_2(1,"乙方送货上门"),
        TRANSPORT_3(2,"以【备注】约定为准");
        private Integer code;
        private String msg;
        TransportWayEnum(Integer code,String msg){
            this.code = code;
            this.msg = msg;
        }
        public static String get(Integer code){
            code = code == null?0:code;
            for(TransportWayEnum transport : values()){
                if(code.equals(transport.getCode())){
                    return transport.getMsg();
                }
            }
            return "";
        }

    }
    @Getter
    enum FirstPaymentEnum{
        PAYMENT_1(0,"发货前7个工作日内"),
        PAYMENT_2(1,"以【备注】约定为准");
        private Integer code;
        private String msg;
        FirstPaymentEnum(Integer code,String msg){
            this.code = code;
            this.msg = msg;
        }
        public static String get(Integer code){
            code = code == null?0:code;
            for(FirstPaymentEnum firstPaymentEnum : values()){
                if(code.equals(firstPaymentEnum.getCode())){
                    return firstPaymentEnum.getMsg();
                }
            }
            return "";
        }
    }
    @Getter
    enum LastPaymentEnum{
        PAYMENT_1(0,"收货后7个工作日内"),
        PAYMENT_2(1,"月结(次月前7个工作日内)"),
        PAYMENT_3(2,"以【备注】约定为准");
        private Integer code;
        private String msg;
        LastPaymentEnum(Integer code,String msg){
            this.code = code;
            this.msg = msg;
        }
        public static String get(Integer code){
            code = code == null?0:code;
            for(LastPaymentEnum lastPaymentEnum : values()){
                if(code.equals(lastPaymentEnum.getCode())){
                    return lastPaymentEnum.getMsg();
                }
            }
            return "";
        }
    }

}
